#version 130

uniform sampler2D tex;
uniform samplerCube cubemap;

varying vec3 fragcoord;

vec4 calc_fog_color(vec4 tex_color)
{
	vec3 lookup = fragcoord;
	if (abs(lookup.x) > abs(lookup.z))
		lookup.z = -lookup.z;
	else
		lookup.x = -lookup.x;

	vec4 sky_color = textureLod(cubemap, lookup, 8.0);
	vec3 fog_sky_mix = mix(gl_Fog.color.rgb, sky_color.rgb, 0.8);

	return vec4(fog_sky_mix.rgb, tex_color.a);
}

void main()
{
	vec4 tex_color = texture2D(tex, gl_TexCoord[0].xy);

	float fog = (gl_Fog.end - gl_FogFragCoord) * gl_Fog.scale;
	fog = clamp(fog, 0.0, 1.0);
	vec4 fog_color = calc_fog_color(tex_color);

#if 0 // This is quite heavy code
	if (tex_color.w <= 0.6 /* && gl_FragCoord.z < 1.0 */) {
		// Do a semi transparent checker pattern blending for fragments
		// below a certain alpha threshold.

		vec2 flip = mod(gl_FragCoord.xy, 2.0);

		if (flip.x < 1.0 && flip.y < 1.0)
			gl_FragColor = mix(fog_color, tex_color, fog);
		else if (flip.x >= 1.0 && flip.y >= 1.0)
			gl_FragColor = mix(fog_color, tex_color, fog);
		else
			gl_FragColor = vec4(0.0);
	} else
		gl_FragColor = mix(fog_color, tex_color, fog);
#else
	gl_FragColor = mix(fog_color, tex_color, fog);
#endif

}

